;;
;; PDDL file for the AIPS2000 Planning Competition
;; based on the data generated by the airport simulator Astras.
;;

;; Author: Sebastian Trueg thisshouldbethecurrentdateandtime :(
;; Created with PreInstancerDomainExporter 0.6 by Sebastian Trueg <trueg@informatik.uni-freiburg.de>
;;


(define (domain airport_fixed_structure)

(:requirements :durative-actions :typing)

(:types airplane segment direction airplanetype)

(:constants
                north
                south - direction

                light
                medium
                heavy - airplanetype

                seg_09Thresh_0_100
                seg_09Help_0_100
                seg_09_0_150
                seg_A_09_0_100
                seg_Rwy_0_1300
                seg_27Thresh_0_100
                seg_27Help_0_100
                seg_27_0_150
                seg_B_27_0_100
                seg_N1_N2_0_100
                seg_N1_A_0_100
                seg_N2_N3_1_0_86
                seg_N2_N3_0_85
                seg_N3_N_0_100
                seg_N_N4_0_100
                seg_N_C_0_100
                seg_N4_N5_1_0_85
                seg_N4_N5_0_86
                seg_N5_N6_0_100
                seg_N6_B_0_100
                seg_C_C2_0_100
                seg_C2_C3_0_100
                seg_C3_C4_0_50
                seg_C3_C_A01_0_100
                seg_C3_C_B01_0_100
                seg_C4_C5_0_50
                seg_C5_C6_0_50
                seg_C5_C_A02_0_100
                seg_C5_C_B02_0_100
                seg_C6_C7_0_100
                seg_A01_0_100
                seg_A02_0_100
                seg_B01_0_100
                seg_B02_0_100
                seg_N2_N3_2_0_86
                seg_N2_N3_3_0_86
                seg_N2_N3_4_0_85
                seg_N2_N3_5_0_86
                seg_N2_N3_6_0_86
                seg_N4_N5_2_0_86
                seg_N4_N5_3_0_86
                seg_N4_N5_4_0_85
                seg_N4_N5_5_0_86
                seg_N4_N5_6_0_86 - segment

                airplane_CFBEG
                airplane_DAEWH
                airplane_WURST
                airplane_HOLGI - airplane
)

(:predicates
                ;; airport information
                (has-type ?a - airplane ?t - airplanetype)
                ;; plane a has type t
                (at-segment ?a - airplane ?s - segment)
                ;; planes are at segments, ie at their end in driving direction
                (facing ?a - airplane ?d - direction)
                ;; planes face into their driving direction

                ;; how the planes affect the airport
                (occupied ?s - segment)
                ;; a plane is in here
                (not_occupied ?s - segment)
                (blocked ?s - segment ?a - airplane)
                ;; segment s is blocked if it is endangered by plane p
                (not_blocked ?s - segment ?a - airplane)

                ;; an airplane may lineup on segment s when facing d
                (is-start-runway ?s - segment ?d - direction)

                ;; airplane a is starting from runway s
                (airborne ?a - airplane ?s - segment)

                (is-moving ?a - airplane)
                (is-pushing ?a - airplane)
                (is-parked ?a - airplane ?s - segment)

                (idled_0)
                (landing_global)
                (landing_started)
                (start_landing)
                (landed_1)
                (idled_1)
                (landed_2)
                (idled_2)
                (landed_last)
                (idled_3)
)

(:functions
                ;; the length of a segment
                (length ?s - segment)

                ;; the number of engines of an airplane
                (engines ?a - airplane)
)

(:durative-action move_seg_A01_0_100_seg_C3_C_A01_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_A01_0_100))
                 (at start (not_occupied seg_C3_C_A01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_WURST))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_A01_0_100)))
                 (at end (not_occupied seg_A01_0_100))
                 (at end (not (at-segment ?a seg_A01_0_100)))

                 (at start (occupied seg_C3_C_A01_0_100))
                 (at start (not (not_occupied seg_C3_C_A01_0_100)))
                 (at start (blocked seg_C3_C_A01_0_100 ?a))
                 (at start (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (at-segment ?a seg_C3_C_A01_0_100))


                )
)

(:durative-action move_seg_C3_C_A01_0_100_seg_C3_C4_0_50_north_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C3_C_A01_0_100))
                 (at start (not_occupied seg_C3_C4_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_WURST))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_HOLGI))

                 (over all (not_occupied seg_C2_C3_0_100))
                 (over all (not_occupied seg_C3_C_B01_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C3_C_A01_0_100)))
                 (at end (not_occupied seg_C3_C_A01_0_100))
                 (at end (not (at-segment ?a seg_C3_C_A01_0_100)))

                 (at start (occupied seg_C3_C4_0_50))
                 (at start (not (not_occupied seg_C3_C4_0_50)))
                 (at start (blocked seg_C3_C4_0_50 ?a))
                 (at start (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (at-segment ?a seg_C3_C4_0_50))
                 (at end (not (facing ?a north)))
                 (at end (facing ?a south))

                 (at end (not (blocked seg_A01_0_100 ?a)))
                 (at end (not_blocked seg_A01_0_100 ?a))

                 (at end (blocked seg_C2_C3_0_100 ?a))
                 (at end (not (not_blocked seg_C2_C3_0_100 ?a)))
                 (at end (blocked seg_C3_C_B01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
                )
)

(:durative-action move_seg_C3_C4_0_50_seg_C4_C5_0_50_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C3_C4_0_50))
                 (at start (not_occupied seg_C4_C5_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_WURST))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C3_C4_0_50)))
                 (at end (not_occupied seg_C3_C4_0_50))
                 (at end (not (at-segment ?a seg_C3_C4_0_50)))

                 (at start (occupied seg_C4_C5_0_50))
                 (at start (not (not_occupied seg_C4_C5_0_50)))
                 (at start (blocked seg_C4_C5_0_50 ?a))
                 (at start (not (not_blocked seg_C4_C5_0_50 ?a)))
                 (at end (at-segment ?a seg_C4_C5_0_50))

                 (at end (not (blocked seg_C2_C3_0_100 ?a)))
                 (at end (not_blocked seg_C2_C3_0_100 ?a))
                 (at end (not (blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (blocked seg_C3_C_B01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_B01_0_100 ?a))

                )
)

(:durative-action move_seg_C4_C5_0_50_seg_C3_C4_0_50_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C4_C5_0_50))
                 (at start (not_occupied seg_C3_C4_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_WURST))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C4_C5_0_50)))
                 (at end (not_occupied seg_C4_C5_0_50))
                 (at end (not (at-segment ?a seg_C4_C5_0_50)))

                 (at start (occupied seg_C3_C4_0_50))
                 (at start (not (not_occupied seg_C3_C4_0_50)))
                 (at start (blocked seg_C3_C4_0_50 ?a))
                 (at start (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (at-segment ?a seg_C3_C4_0_50))

                 (at end (not (blocked seg_C5_C6_0_50 ?a)))
                 (at end (not_blocked seg_C5_C6_0_50 ?a))
                 (at end (not (blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_A02_0_100 ?a))
                 (at end (not (blocked seg_C5_C_B02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_B02_0_100 ?a))

                )
)

(:durative-action move_seg_C3_C4_0_50_seg_C2_C3_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C3_C4_0_50))
                 (at start (not_occupied seg_C2_C3_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_WURST))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_C3_C_A01_0_100))
                 (over all (not_occupied seg_C3_C_B01_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C3_C4_0_50)))
                 (at end (not_occupied seg_C3_C4_0_50))
                 (at end (not (at-segment ?a seg_C3_C4_0_50)))

                 (at start (occupied seg_C2_C3_0_100))
                 (at start (not (not_occupied seg_C2_C3_0_100)))
                 (at start (blocked seg_C2_C3_0_100 ?a))
                 (at start (not (not_blocked seg_C2_C3_0_100 ?a)))
                 (at end (at-segment ?a seg_C2_C3_0_100))

                 (at end (not (blocked seg_C4_C5_0_50 ?a)))
                 (at end (not_blocked seg_C4_C5_0_50 ?a))

                 (at end (blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (blocked seg_C3_C_B01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
                )
)

(:durative-action move_seg_C2_C3_0_100_seg_C_C2_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C2_C3_0_100))
                 (at start (not_occupied seg_C_C2_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C_C2_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C_C2_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C_C2_0_100 airplane_WURST))
                 (at start (not_blocked seg_C_C2_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C2_C3_0_100)))
                 (at end (not_occupied seg_C2_C3_0_100))
                 (at end (not (at-segment ?a seg_C2_C3_0_100)))

                 (at start (occupied seg_C_C2_0_100))
                 (at start (not (not_occupied seg_C_C2_0_100)))
                 (at start (blocked seg_C_C2_0_100 ?a))
                 (at start (not (not_blocked seg_C_C2_0_100 ?a)))
                 (at end (at-segment ?a seg_C_C2_0_100))

                 (at end (not (blocked seg_C3_C4_0_50 ?a)))
                 (at end (not_blocked seg_C3_C4_0_50 ?a))
                 (at end (not (blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (blocked seg_C3_C_B01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_B01_0_100 ?a))

                )
)

(:durative-action move_seg_C_C2_0_100_seg_N_C_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C_C2_0_100))
                 (at start (not_occupied seg_N_C_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N_C_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N_C_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N_C_0_100 airplane_WURST))
                 (at start (not_blocked seg_N_C_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C_C2_0_100)))
                 (at end (not_occupied seg_C_C2_0_100))
                 (at end (not (at-segment ?a seg_C_C2_0_100)))

                 (at start (occupied seg_N_C_0_100))
                 (at start (not (not_occupied seg_N_C_0_100)))
                 (at start (blocked seg_N_C_0_100 ?a))
                 (at start (not (not_blocked seg_N_C_0_100 ?a)))
                 (at end (at-segment ?a seg_N_C_0_100))

                 (at end (not (blocked seg_C2_C3_0_100 ?a)))
                 (at end (not_blocked seg_C2_C3_0_100 ?a))

                )
)

(:durative-action move_seg_N_C_0_100_seg_N3_N_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N_C_0_100))
                 (at start (not_occupied seg_N3_N_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N3_N_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N3_N_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N3_N_0_100 airplane_WURST))
                 (at start (not_blocked seg_N3_N_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_N_N4_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_N_C_0_100)))
                 (at end (not_occupied seg_N_C_0_100))
                 (at end (not (at-segment ?a seg_N_C_0_100)))

                 (at start (occupied seg_N3_N_0_100))
                 (at start (not (not_occupied seg_N3_N_0_100)))
                 (at start (blocked seg_N3_N_0_100 ?a))
                 (at start (not (not_blocked seg_N3_N_0_100 ?a)))
                 (at end (at-segment ?a seg_N3_N_0_100))

                 (at end (not (blocked seg_C_C2_0_100 ?a)))
                 (at end (not_blocked seg_C_C2_0_100 ?a))

                 (at end (blocked seg_N_N4_0_100 ?a))
                 (at end (not (not_blocked seg_N_N4_0_100 ?a)))
                )
)

(:durative-action move_seg_N3_N_0_100_seg_N2_N3_0_85_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N3_N_0_100))
                 (at start (not_occupied seg_N2_N3_0_85))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_0_85 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_0_85 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_0_85 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_0_85 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N3_N_0_100)))
                 (at end (not_occupied seg_N3_N_0_100))
                 (at end (not (at-segment ?a seg_N3_N_0_100)))

                 (at start (occupied seg_N2_N3_0_85))
                 (at start (not (not_occupied seg_N2_N3_0_85)))
                 (at start (blocked seg_N2_N3_0_85 ?a))
                 (at start (not (not_blocked seg_N2_N3_0_85 ?a)))
                 (at end (at-segment ?a seg_N2_N3_0_85))

                 (at end (not (blocked seg_N_N4_0_100 ?a)))
                 (at end (not_blocked seg_N_N4_0_100 ?a))
                 (at end (not (blocked seg_N_C_0_100 ?a)))
                 (at end (not_blocked seg_N_C_0_100 ?a))

                )
)

(:durative-action move_seg_N2_N3_0_85_seg_N2_N3_6_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_0_85))
                 (at start (not_occupied seg_N2_N3_6_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_6_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_6_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_6_0_86 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_6_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_0_85)))
                 (at end (not_occupied seg_N2_N3_0_85))
                 (at end (not (at-segment ?a seg_N2_N3_0_85)))

                 (at start (occupied seg_N2_N3_6_0_86))
                 (at start (not (not_occupied seg_N2_N3_6_0_86)))
                 (at start (blocked seg_N2_N3_6_0_86 ?a))
                 (at start (not (not_blocked seg_N2_N3_6_0_86 ?a)))
                 (at end (at-segment ?a seg_N2_N3_6_0_86))

                 (at end (not (blocked seg_N3_N_0_100 ?a)))
                 (at end (not_blocked seg_N3_N_0_100 ?a))

                )
)

(:durative-action move_seg_N2_N3_6_0_86_seg_N2_N3_5_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_6_0_86))
                 (at start (not_occupied seg_N2_N3_5_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_5_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_5_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_5_0_86 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_5_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_6_0_86)))
                 (at end (not_occupied seg_N2_N3_6_0_86))
                 (at end (not (at-segment ?a seg_N2_N3_6_0_86)))

                 (at start (occupied seg_N2_N3_5_0_86))
                 (at start (not (not_occupied seg_N2_N3_5_0_86)))
                 (at start (blocked seg_N2_N3_5_0_86 ?a))
                 (at start (not (not_blocked seg_N2_N3_5_0_86 ?a)))
                 (at end (at-segment ?a seg_N2_N3_5_0_86))

                 (at end (not (blocked seg_N2_N3_0_85 ?a)))
                 (at end (not_blocked seg_N2_N3_0_85 ?a))

                )
)

(:durative-action move_seg_N2_N3_5_0_86_seg_N2_N3_4_0_85_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_5_0_86))
                 (at start (not_occupied seg_N2_N3_4_0_85))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_4_0_85 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_4_0_85 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_4_0_85 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_4_0_85 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_5_0_86)))
                 (at end (not_occupied seg_N2_N3_5_0_86))
                 (at end (not (at-segment ?a seg_N2_N3_5_0_86)))

                 (at start (occupied seg_N2_N3_4_0_85))
                 (at start (not (not_occupied seg_N2_N3_4_0_85)))
                 (at start (blocked seg_N2_N3_4_0_85 ?a))
                 (at start (not (not_blocked seg_N2_N3_4_0_85 ?a)))
                 (at end (at-segment ?a seg_N2_N3_4_0_85))

                 (at end (not (blocked seg_N2_N3_6_0_86 ?a)))
                 (at end (not_blocked seg_N2_N3_6_0_86 ?a))

                )
)

(:durative-action move_seg_N2_N3_4_0_85_seg_N2_N3_3_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_4_0_85))
                 (at start (not_occupied seg_N2_N3_3_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_3_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_3_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_3_0_86 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_3_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_4_0_85)))
                 (at end (not_occupied seg_N2_N3_4_0_85))
                 (at end (not (at-segment ?a seg_N2_N3_4_0_85)))

                 (at start (occupied seg_N2_N3_3_0_86))
                 (at start (not (not_occupied seg_N2_N3_3_0_86)))
                 (at start (blocked seg_N2_N3_3_0_86 ?a))
                 (at start (not (not_blocked seg_N2_N3_3_0_86 ?a)))
                 (at end (at-segment ?a seg_N2_N3_3_0_86))

                 (at end (not (blocked seg_N2_N3_5_0_86 ?a)))
                 (at end (not_blocked seg_N2_N3_5_0_86 ?a))

                )
)

(:durative-action move_seg_N2_N3_3_0_86_seg_N2_N3_2_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_3_0_86))
                 (at start (not_occupied seg_N2_N3_2_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_2_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_2_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_2_0_86 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_2_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_3_0_86)))
                 (at end (not_occupied seg_N2_N3_3_0_86))
                 (at end (not (at-segment ?a seg_N2_N3_3_0_86)))

                 (at start (occupied seg_N2_N3_2_0_86))
                 (at start (not (not_occupied seg_N2_N3_2_0_86)))
                 (at start (blocked seg_N2_N3_2_0_86 ?a))
                 (at start (not (not_blocked seg_N2_N3_2_0_86 ?a)))
                 (at end (at-segment ?a seg_N2_N3_2_0_86))

                 (at end (not (blocked seg_N2_N3_4_0_85 ?a)))
                 (at end (not_blocked seg_N2_N3_4_0_85 ?a))

                )
)

(:durative-action move_seg_N2_N3_2_0_86_seg_N2_N3_1_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_2_0_86))
                 (at start (not_occupied seg_N2_N3_1_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N2_N3_1_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N2_N3_1_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N2_N3_1_0_86 airplane_WURST))
                 (at start (not_blocked seg_N2_N3_1_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_2_0_86)))
                 (at end (not_occupied seg_N2_N3_2_0_86))
                 (at end (not (at-segment ?a seg_N2_N3_2_0_86)))

                 (at start (occupied seg_N2_N3_1_0_86))
                 (at start (not (not_occupied seg_N2_N3_1_0_86)))
                 (at start (blocked seg_N2_N3_1_0_86 ?a))
                 (at start (not (not_blocked seg_N2_N3_1_0_86 ?a)))
                 (at end (at-segment ?a seg_N2_N3_1_0_86))

                 (at end (not (blocked seg_N2_N3_3_0_86 ?a)))
                 (at end (not_blocked seg_N2_N3_3_0_86 ?a))

                )
)

(:durative-action move_seg_N2_N3_1_0_86_seg_N1_N2_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N2_N3_1_0_86))
                 (at start (not_occupied seg_N1_N2_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N1_N2_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N1_N2_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N1_N2_0_100 airplane_WURST))
                 (at start (not_blocked seg_N1_N2_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N2_N3_1_0_86)))
                 (at end (not_occupied seg_N2_N3_1_0_86))
                 (at end (not (at-segment ?a seg_N2_N3_1_0_86)))

                 (at start (occupied seg_N1_N2_0_100))
                 (at start (not (not_occupied seg_N1_N2_0_100)))
                 (at start (blocked seg_N1_N2_0_100 ?a))
                 (at start (not (not_blocked seg_N1_N2_0_100 ?a)))
                 (at end (at-segment ?a seg_N1_N2_0_100))

                 (at end (not (blocked seg_N2_N3_2_0_86 ?a)))
                 (at end (not_blocked seg_N2_N3_2_0_86 ?a))

                )
)

(:durative-action move_seg_N1_N2_0_100_seg_N1_A_0_100_north_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N1_N2_0_100))
                 (at start (not_occupied seg_N1_A_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N1_A_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N1_A_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N1_A_0_100 airplane_WURST))
                 (at start (not_blocked seg_N1_A_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N1_N2_0_100)))
                 (at end (not_occupied seg_N1_N2_0_100))
                 (at end (not (at-segment ?a seg_N1_N2_0_100)))

                 (at start (occupied seg_N1_A_0_100))
                 (at start (not (not_occupied seg_N1_A_0_100)))
                 (at start (blocked seg_N1_A_0_100 ?a))
                 (at start (not (not_blocked seg_N1_A_0_100 ?a)))
                 (at end (at-segment ?a seg_N1_A_0_100))
                 (at end (not (facing ?a north)))
                 (at end (facing ?a south))

                 (at end (not (blocked seg_N2_N3_1_0_86 ?a)))
                 (at end (not_blocked seg_N2_N3_1_0_86 ?a))

                )
)

(:durative-action move_seg_N1_A_0_100_seg_A_09_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_N1_A_0_100))
                 (at start (not_occupied seg_A_09_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_A_09_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_A_09_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_A_09_0_100 airplane_WURST))
                 (at start (not_blocked seg_A_09_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N1_A_0_100)))
                 (at end (not_occupied seg_N1_A_0_100))
                 (at end (not (at-segment ?a seg_N1_A_0_100)))

                 (at start (occupied seg_A_09_0_100))
                 (at start (not (not_occupied seg_A_09_0_100)))
                 (at start (blocked seg_A_09_0_100 ?a))
                 (at start (not (not_blocked seg_A_09_0_100 ?a)))
                 (at end (at-segment ?a seg_A_09_0_100))

                 (at end (not (blocked seg_N1_N2_0_100 ?a)))
                 (at end (not_blocked seg_N1_N2_0_100 ?a))

                )
)

(:durative-action move_seg_A_09_0_100_seg_09_0_150_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_A_09_0_100))
                 (at start (not_occupied seg_09_0_150))
                 (at start (landing_started))
                 (at start (not_blocked seg_09_0_150 airplane_CFBEG))
                 (at start (not_blocked seg_09_0_150 airplane_DAEWH))
                 (at start (not_blocked seg_09_0_150 airplane_WURST))
                 (at start (not_blocked seg_09_0_150 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_A_09_0_100)))
                 (at end (not_occupied seg_A_09_0_100))
                 (at end (not (at-segment ?a seg_A_09_0_100)))

                 (at start (occupied seg_09_0_150))
                 (at start (not (not_occupied seg_09_0_150)))
                 (at start (blocked seg_09_0_150 ?a))
                 (at start (not (not_blocked seg_09_0_150 ?a)))
                 (at end (at-segment ?a seg_09_0_150))

                 (at end (not (blocked seg_N1_A_0_100 ?a)))
                 (at end (not_blocked seg_N1_A_0_100 ?a))

                )
)

(:durative-action move_seg_09_0_150_seg_Rwy_0_1300_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 5)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_09_0_150))
                 (at start (not_occupied seg_Rwy_0_1300))
                 (at start (landing_started))
                 (at start (not_blocked seg_Rwy_0_1300 airplane_CFBEG))
                 (at start (not_blocked seg_Rwy_0_1300 airplane_DAEWH))
                 (at start (not_blocked seg_Rwy_0_1300 airplane_WURST))
                 (at start (not_blocked seg_Rwy_0_1300 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_09_0_150)))
                 (at end (not_occupied seg_09_0_150))
                 (at end (not (at-segment ?a seg_09_0_150)))

                 (at start (occupied seg_Rwy_0_1300))
                 (at start (not (not_occupied seg_Rwy_0_1300)))
                 (at start (blocked seg_Rwy_0_1300 ?a))
                 (at start (not (not_blocked seg_Rwy_0_1300 ?a)))
                 (at end (at-segment ?a seg_Rwy_0_1300))

                 (at end (not (blocked seg_A_09_0_100 ?a)))
                 (at end (not_blocked seg_A_09_0_100 ?a))

                )
)

(:durative-action move_seg_Rwy_0_1300_seg_27_0_150_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 43)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_Rwy_0_1300))
                 (at start (not_occupied seg_27_0_150))
                 (at start (landing_started))
                 (at start (not_blocked seg_27_0_150 airplane_CFBEG))
                 (at start (not_blocked seg_27_0_150 airplane_DAEWH))
                 (at start (not_blocked seg_27_0_150 airplane_WURST))
                 (at start (not_blocked seg_27_0_150 airplane_HOLGI))

                 (over all (not_occupied seg_09_0_150))
              )

 :effect        (and
                 (at end (not (occupied seg_Rwy_0_1300)))
                 (at end (not_occupied seg_Rwy_0_1300))
                 (at end (not (at-segment ?a seg_Rwy_0_1300)))

                 (at start (occupied seg_27_0_150))
                 (at start (not (not_occupied seg_27_0_150)))
                 (at start (blocked seg_27_0_150 ?a))
                 (at start (not (not_blocked seg_27_0_150 ?a)))
                 (at end (at-segment ?a seg_27_0_150))


                )
)

(:durative-action move_seg_27_0_150_seg_B_27_0_100_south_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 5)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_27_0_150))
                 (at start (not_occupied seg_B_27_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_B_27_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_B_27_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_B_27_0_100 airplane_WURST))
                 (at start (not_blocked seg_B_27_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_27Help_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_27_0_150)))
                 (at end (not_occupied seg_27_0_150))
                 (at end (not (at-segment ?a seg_27_0_150)))

                 (at start (occupied seg_B_27_0_100))
                 (at start (not (not_occupied seg_B_27_0_100)))
                 (at start (blocked seg_B_27_0_100 ?a))
                 (at start (not (not_blocked seg_B_27_0_100 ?a)))
                 (at end (at-segment ?a seg_B_27_0_100))
                 (at end (not (facing ?a south)))
                 (at end (facing ?a north))

                 (at end (not (blocked seg_09_0_150 ?a)))
                 (at end (not_blocked seg_09_0_150 ?a))
                 (at end (not (blocked seg_Rwy_0_1300 ?a)))
                 (at end (not_blocked seg_Rwy_0_1300 ?a))

                 (at end (blocked seg_27Help_0_100 ?a))
                 (at end (not (not_blocked seg_27Help_0_100 ?a)))
                )
)

(:durative-action move_seg_B_27_0_100_seg_N6_B_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_B_27_0_100))
                 (at start (not_occupied seg_N6_B_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N6_B_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N6_B_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N6_B_0_100 airplane_WURST))
                 (at start (not_blocked seg_N6_B_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_B_27_0_100)))
                 (at end (not_occupied seg_B_27_0_100))
                 (at end (not (at-segment ?a seg_B_27_0_100)))

                 (at start (occupied seg_N6_B_0_100))
                 (at start (not (not_occupied seg_N6_B_0_100)))
                 (at start (blocked seg_N6_B_0_100 ?a))
                 (at start (not (not_blocked seg_N6_B_0_100 ?a)))
                 (at end (at-segment ?a seg_N6_B_0_100))

                 (at end (not (blocked seg_27_0_150 ?a)))
                 (at end (not_blocked seg_27_0_150 ?a))
                 (at end (not (blocked seg_27Help_0_100 ?a)))
                 (at end (not_blocked seg_27Help_0_100 ?a))

                )
)

(:durative-action move_seg_N6_B_0_100_seg_N5_N6_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N6_B_0_100))
                 (at start (not_occupied seg_N5_N6_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N5_N6_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N5_N6_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N5_N6_0_100 airplane_WURST))
                 (at start (not_blocked seg_N5_N6_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N6_B_0_100)))
                 (at end (not_occupied seg_N6_B_0_100))
                 (at end (not (at-segment ?a seg_N6_B_0_100)))

                 (at start (occupied seg_N5_N6_0_100))
                 (at start (not (not_occupied seg_N5_N6_0_100)))
                 (at start (blocked seg_N5_N6_0_100 ?a))
                 (at start (not (not_blocked seg_N5_N6_0_100 ?a)))
                 (at end (at-segment ?a seg_N5_N6_0_100))

                 (at end (not (blocked seg_B_27_0_100 ?a)))
                 (at end (not_blocked seg_B_27_0_100 ?a))

                )
)

(:durative-action move_seg_N5_N6_0_100_seg_N4_N5_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N5_N6_0_100))
                 (at start (not_occupied seg_N4_N5_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_0_86 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N5_N6_0_100)))
                 (at end (not_occupied seg_N5_N6_0_100))
                 (at end (not (at-segment ?a seg_N5_N6_0_100)))

                 (at start (occupied seg_N4_N5_0_86))
                 (at start (not (not_occupied seg_N4_N5_0_86)))
                 (at start (blocked seg_N4_N5_0_86 ?a))
                 (at start (not (not_blocked seg_N4_N5_0_86 ?a)))
                 (at end (at-segment ?a seg_N4_N5_0_86))

                 (at end (not (blocked seg_N6_B_0_100 ?a)))
                 (at end (not_blocked seg_N6_B_0_100 ?a))

                )
)

(:durative-action move_seg_N4_N5_0_86_seg_N4_N5_6_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_0_86))
                 (at start (not_occupied seg_N4_N5_6_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_6_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_6_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_6_0_86 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_6_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_0_86)))
                 (at end (not_occupied seg_N4_N5_0_86))
                 (at end (not (at-segment ?a seg_N4_N5_0_86)))

                 (at start (occupied seg_N4_N5_6_0_86))
                 (at start (not (not_occupied seg_N4_N5_6_0_86)))
                 (at start (blocked seg_N4_N5_6_0_86 ?a))
                 (at start (not (not_blocked seg_N4_N5_6_0_86 ?a)))
                 (at end (at-segment ?a seg_N4_N5_6_0_86))

                 (at end (not (blocked seg_N5_N6_0_100 ?a)))
                 (at end (not_blocked seg_N5_N6_0_100 ?a))

                )
)

(:durative-action move_seg_N4_N5_6_0_86_seg_N4_N5_5_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_6_0_86))
                 (at start (not_occupied seg_N4_N5_5_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_5_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_5_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_5_0_86 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_5_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_6_0_86)))
                 (at end (not_occupied seg_N4_N5_6_0_86))
                 (at end (not (at-segment ?a seg_N4_N5_6_0_86)))

                 (at start (occupied seg_N4_N5_5_0_86))
                 (at start (not (not_occupied seg_N4_N5_5_0_86)))
                 (at start (blocked seg_N4_N5_5_0_86 ?a))
                 (at start (not (not_blocked seg_N4_N5_5_0_86 ?a)))
                 (at end (at-segment ?a seg_N4_N5_5_0_86))

                 (at end (not (blocked seg_N4_N5_0_86 ?a)))
                 (at end (not_blocked seg_N4_N5_0_86 ?a))

                )
)

(:durative-action move_seg_N4_N5_5_0_86_seg_N4_N5_4_0_85_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_5_0_86))
                 (at start (not_occupied seg_N4_N5_4_0_85))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_4_0_85 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_4_0_85 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_4_0_85 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_4_0_85 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_5_0_86)))
                 (at end (not_occupied seg_N4_N5_5_0_86))
                 (at end (not (at-segment ?a seg_N4_N5_5_0_86)))

                 (at start (occupied seg_N4_N5_4_0_85))
                 (at start (not (not_occupied seg_N4_N5_4_0_85)))
                 (at start (blocked seg_N4_N5_4_0_85 ?a))
                 (at start (not (not_blocked seg_N4_N5_4_0_85 ?a)))
                 (at end (at-segment ?a seg_N4_N5_4_0_85))

                 (at end (not (blocked seg_N4_N5_6_0_86 ?a)))
                 (at end (not_blocked seg_N4_N5_6_0_86 ?a))

                )
)

(:durative-action move_seg_N4_N5_4_0_85_seg_N4_N5_3_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_4_0_85))
                 (at start (not_occupied seg_N4_N5_3_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_3_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_3_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_3_0_86 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_3_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_4_0_85)))
                 (at end (not_occupied seg_N4_N5_4_0_85))
                 (at end (not (at-segment ?a seg_N4_N5_4_0_85)))

                 (at start (occupied seg_N4_N5_3_0_86))
                 (at start (not (not_occupied seg_N4_N5_3_0_86)))
                 (at start (blocked seg_N4_N5_3_0_86 ?a))
                 (at start (not (not_blocked seg_N4_N5_3_0_86 ?a)))
                 (at end (at-segment ?a seg_N4_N5_3_0_86))

                 (at end (not (blocked seg_N4_N5_5_0_86 ?a)))
                 (at end (not_blocked seg_N4_N5_5_0_86 ?a))

                )
)

(:durative-action move_seg_N4_N5_3_0_86_seg_N4_N5_2_0_86_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_3_0_86))
                 (at start (not_occupied seg_N4_N5_2_0_86))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_2_0_86 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_2_0_86 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_2_0_86 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_2_0_86 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_3_0_86)))
                 (at end (not_occupied seg_N4_N5_3_0_86))
                 (at end (not (at-segment ?a seg_N4_N5_3_0_86)))

                 (at start (occupied seg_N4_N5_2_0_86))
                 (at start (not (not_occupied seg_N4_N5_2_0_86)))
                 (at start (blocked seg_N4_N5_2_0_86 ?a))
                 (at start (not (not_blocked seg_N4_N5_2_0_86 ?a)))
                 (at end (at-segment ?a seg_N4_N5_2_0_86))

                 (at end (not (blocked seg_N4_N5_4_0_85 ?a)))
                 (at end (not_blocked seg_N4_N5_4_0_85 ?a))

                )
)

(:durative-action move_seg_N4_N5_2_0_86_seg_N4_N5_1_0_85_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_2_0_86))
                 (at start (not_occupied seg_N4_N5_1_0_85))
                 (at start (landing_started))
                 (at start (not_blocked seg_N4_N5_1_0_85 airplane_CFBEG))
                 (at start (not_blocked seg_N4_N5_1_0_85 airplane_DAEWH))
                 (at start (not_blocked seg_N4_N5_1_0_85 airplane_WURST))
                 (at start (not_blocked seg_N4_N5_1_0_85 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_2_0_86)))
                 (at end (not_occupied seg_N4_N5_2_0_86))
                 (at end (not (at-segment ?a seg_N4_N5_2_0_86)))

                 (at start (occupied seg_N4_N5_1_0_85))
                 (at start (not (not_occupied seg_N4_N5_1_0_85)))
                 (at start (blocked seg_N4_N5_1_0_85 ?a))
                 (at start (not (not_blocked seg_N4_N5_1_0_85 ?a)))
                 (at end (at-segment ?a seg_N4_N5_1_0_85))

                 (at end (not (blocked seg_N4_N5_3_0_86 ?a)))
                 (at end (not_blocked seg_N4_N5_3_0_86 ?a))

                )
)

(:durative-action move_seg_N4_N5_1_0_85_seg_N_N4_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 2)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N4_N5_1_0_85))
                 (at start (not_occupied seg_N_N4_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N_N4_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N_N4_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N_N4_0_100 airplane_WURST))
                 (at start (not_blocked seg_N_N4_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N4_N5_1_0_85)))
                 (at end (not_occupied seg_N4_N5_1_0_85))
                 (at end (not (at-segment ?a seg_N4_N5_1_0_85)))

                 (at start (occupied seg_N_N4_0_100))
                 (at start (not (not_occupied seg_N_N4_0_100)))
                 (at start (blocked seg_N_N4_0_100 ?a))
                 (at start (not (not_blocked seg_N_N4_0_100 ?a)))
                 (at end (at-segment ?a seg_N_N4_0_100))

                 (at end (not (blocked seg_N4_N5_2_0_86 ?a)))
                 (at end (not_blocked seg_N4_N5_2_0_86 ?a))

                )
)

(:durative-action move_seg_N_N4_0_100_seg_N_C_0_100_north_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_N_N4_0_100))
                 (at start (not_occupied seg_N_C_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_N_C_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_N_C_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_N_C_0_100 airplane_WURST))
                 (at start (not_blocked seg_N_C_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_N3_N_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_N_N4_0_100)))
                 (at end (not_occupied seg_N_N4_0_100))
                 (at end (not (at-segment ?a seg_N_N4_0_100)))

                 (at start (occupied seg_N_C_0_100))
                 (at start (not (not_occupied seg_N_C_0_100)))
                 (at start (blocked seg_N_C_0_100 ?a))
                 (at start (not (not_blocked seg_N_C_0_100 ?a)))
                 (at end (at-segment ?a seg_N_C_0_100))
                 (at end (not (facing ?a north)))
                 (at end (facing ?a south))

                 (at end (not (blocked seg_N4_N5_1_0_85 ?a)))
                 (at end (not_blocked seg_N4_N5_1_0_85 ?a))

                 (at end (blocked seg_N3_N_0_100 ?a))
                 (at end (not (not_blocked seg_N3_N_0_100 ?a)))
                )
)

(:durative-action move_seg_N_C_0_100_seg_C_C2_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_N_C_0_100))
                 (at start (not_occupied seg_C_C2_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C_C2_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C_C2_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C_C2_0_100 airplane_WURST))
                 (at start (not_blocked seg_C_C2_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_N_C_0_100)))
                 (at end (not_occupied seg_N_C_0_100))
                 (at end (not (at-segment ?a seg_N_C_0_100)))

                 (at start (occupied seg_C_C2_0_100))
                 (at start (not (not_occupied seg_C_C2_0_100)))
                 (at start (blocked seg_C_C2_0_100 ?a))
                 (at start (not (not_blocked seg_C_C2_0_100 ?a)))
                 (at end (at-segment ?a seg_C_C2_0_100))

                 (at end (not (blocked seg_N3_N_0_100 ?a)))
                 (at end (not_blocked seg_N3_N_0_100 ?a))
                 (at end (not (blocked seg_N_N4_0_100 ?a)))
                 (at end (not_blocked seg_N_N4_0_100 ?a))

                )
)

(:durative-action move_seg_C_C2_0_100_seg_C2_C3_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C_C2_0_100))
                 (at start (not_occupied seg_C2_C3_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_WURST))
                 (at start (not_blocked seg_C2_C3_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C_C2_0_100)))
                 (at end (not_occupied seg_C_C2_0_100))
                 (at end (not (at-segment ?a seg_C_C2_0_100)))

                 (at start (occupied seg_C2_C3_0_100))
                 (at start (not (not_occupied seg_C2_C3_0_100)))
                 (at start (blocked seg_C2_C3_0_100 ?a))
                 (at start (not (not_blocked seg_C2_C3_0_100 ?a)))
                 (at end (at-segment ?a seg_C2_C3_0_100))

                 (at end (not (blocked seg_N_C_0_100 ?a)))
                 (at end (not_blocked seg_N_C_0_100 ?a))

                )
)

(:durative-action move_seg_C2_C3_0_100_seg_C3_C_A01_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C2_C3_0_100))
                 (at start (not_occupied seg_C3_C_A01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_WURST))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_C3_C4_0_50))
                 (over all (not_occupied seg_C3_C_B01_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C2_C3_0_100)))
                 (at end (not_occupied seg_C2_C3_0_100))
                 (at end (not (at-segment ?a seg_C2_C3_0_100)))

                 (at start (occupied seg_C3_C_A01_0_100))
                 (at start (not (not_occupied seg_C3_C_A01_0_100)))
                 (at start (blocked seg_C3_C_A01_0_100 ?a))
                 (at start (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (at-segment ?a seg_C3_C_A01_0_100))

                 (at end (not (blocked seg_C_C2_0_100 ?a)))
                 (at end (not_blocked seg_C_C2_0_100 ?a))

                 (at end (blocked seg_C3_C4_0_50 ?a))
                 (at end (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (blocked seg_C3_C_B01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
                )
)

(:durative-action move_seg_C3_C_A01_0_100_seg_A01_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C3_C_A01_0_100))
                 (at start (not_occupied seg_A01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_A01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_A01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_A01_0_100 airplane_WURST))
                 (at start (not_blocked seg_A01_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C3_C_A01_0_100)))
                 (at end (not_occupied seg_C3_C_A01_0_100))
                 (at end (not (at-segment ?a seg_C3_C_A01_0_100)))

                 (at start (occupied seg_A01_0_100))
                 (at start (not (not_occupied seg_A01_0_100)))
                 (at start (blocked seg_A01_0_100 ?a))
                 (at start (not (not_blocked seg_A01_0_100 ?a)))
                 (at end (at-segment ?a seg_A01_0_100))

                 (at end (not (blocked seg_C2_C3_0_100 ?a)))
                 (at end (not_blocked seg_C2_C3_0_100 ?a))
                 (at end (not (blocked seg_C3_C4_0_50 ?a)))
                 (at end (not_blocked seg_C3_C4_0_50 ?a))
                 (at end (not (blocked seg_C3_C_B01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_B01_0_100 ?a))

                )
)

(:durative-action move_seg_A02_0_100_seg_C5_C_A02_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_A02_0_100))
                 (at start (not_occupied seg_C5_C_A02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_WURST))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_A02_0_100)))
                 (at end (not_occupied seg_A02_0_100))
                 (at end (not (at-segment ?a seg_A02_0_100)))

                 (at start (occupied seg_C5_C_A02_0_100))
                 (at start (not (not_occupied seg_C5_C_A02_0_100)))
                 (at start (blocked seg_C5_C_A02_0_100 ?a))
                 (at start (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (at-segment ?a seg_C5_C_A02_0_100))


                )
)

(:durative-action move_seg_C5_C_A02_0_100_seg_C5_C6_0_50_north_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C5_C_A02_0_100))
                 (at start (not_occupied seg_C5_C6_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_WURST))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_HOLGI))

                 (over all (not_occupied seg_C4_C5_0_50))
                 (over all (not_occupied seg_C5_C_B02_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C5_C_A02_0_100)))
                 (at end (not_occupied seg_C5_C_A02_0_100))
                 (at end (not (at-segment ?a seg_C5_C_A02_0_100)))

                 (at start (occupied seg_C5_C6_0_50))
                 (at start (not (not_occupied seg_C5_C6_0_50)))
                 (at start (blocked seg_C5_C6_0_50 ?a))
                 (at start (not (not_blocked seg_C5_C6_0_50 ?a)))
                 (at end (at-segment ?a seg_C5_C6_0_50))
                 (at end (not (facing ?a north)))
                 (at end (facing ?a south))

                 (at end (not (blocked seg_A02_0_100 ?a)))
                 (at end (not_blocked seg_A02_0_100 ?a))

                 (at end (blocked seg_C4_C5_0_50 ?a))
                 (at end (not (not_blocked seg_C4_C5_0_50 ?a)))
                 (at end (blocked seg_C5_C_B02_0_100 ?a))
                 (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
                )
)

(:durative-action move_seg_C5_C6_0_50_seg_C6_C7_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C5_C6_0_50))
                 (at start (not_occupied seg_C6_C7_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_WURST))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C5_C6_0_50)))
                 (at end (not_occupied seg_C5_C6_0_50))
                 (at end (not (at-segment ?a seg_C5_C6_0_50)))

                 (at start (occupied seg_C6_C7_0_100))
                 (at start (not (not_occupied seg_C6_C7_0_100)))
                 (at start (blocked seg_C6_C7_0_100 ?a))
                 (at start (not (not_blocked seg_C6_C7_0_100 ?a)))
                 (at end (at-segment ?a seg_C6_C7_0_100))

                 (at end (not (blocked seg_C4_C5_0_50 ?a)))
                 (at end (not_blocked seg_C4_C5_0_50 ?a))
                 (at end (not (blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_A02_0_100 ?a))
                 (at end (not (blocked seg_C5_C_B02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_B02_0_100 ?a))

                )
)

(:durative-action move_seg_C6_C7_0_100_seg_C5_C6_0_50_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C6_C7_0_100))
                 (at start (not_occupied seg_C5_C6_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_WURST))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C6_C7_0_100)))
                 (at end (not_occupied seg_C6_C7_0_100))
                 (at end (not (at-segment ?a seg_C6_C7_0_100)))

                 (at start (occupied seg_C5_C6_0_50))
                 (at start (not (not_occupied seg_C5_C6_0_50)))
                 (at start (blocked seg_C5_C6_0_50 ?a))
                 (at start (not (not_blocked seg_C5_C6_0_50 ?a)))
                 (at end (at-segment ?a seg_C5_C6_0_50))


                )
)

(:durative-action move_seg_C5_C6_0_50_seg_C4_C5_0_50_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C5_C6_0_50))
                 (at start (not_occupied seg_C4_C5_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_WURST))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_HOLGI))

                 (over all (not_occupied seg_C5_C_A02_0_100))
                 (over all (not_occupied seg_C5_C_B02_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C5_C6_0_50)))
                 (at end (not_occupied seg_C5_C6_0_50))
                 (at end (not (at-segment ?a seg_C5_C6_0_50)))

                 (at start (occupied seg_C4_C5_0_50))
                 (at start (not (not_occupied seg_C4_C5_0_50)))
                 (at start (blocked seg_C4_C5_0_50 ?a))
                 (at start (not (not_blocked seg_C4_C5_0_50 ?a)))
                 (at end (at-segment ?a seg_C4_C5_0_50))

                 (at end (not (blocked seg_C6_C7_0_100 ?a)))
                 (at end (not_blocked seg_C6_C7_0_100 ?a))

                 (at end (blocked seg_C5_C_A02_0_100 ?a))
                 (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (blocked seg_C5_C_B02_0_100 ?a))
                 (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
                )
)

(:durative-action move_seg_C2_C3_0_100_seg_C3_C4_0_50_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C2_C3_0_100))
                 (at start (not_occupied seg_C3_C4_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_WURST))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_HOLGI))

                 (over all (not_occupied seg_C3_C_A01_0_100))
                 (over all (not_occupied seg_C3_C_B01_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C2_C3_0_100)))
                 (at end (not_occupied seg_C2_C3_0_100))
                 (at end (not (at-segment ?a seg_C2_C3_0_100)))

                 (at start (occupied seg_C3_C4_0_50))
                 (at start (not (not_occupied seg_C3_C4_0_50)))
                 (at start (blocked seg_C3_C4_0_50 ?a))
                 (at start (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (at-segment ?a seg_C3_C4_0_50))

                 (at end (not (blocked seg_C_C2_0_100 ?a)))
                 (at end (not_blocked seg_C_C2_0_100 ?a))

                 (at end (blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (blocked seg_C3_C_B01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
                )
)

(:durative-action move_seg_C4_C5_0_50_seg_C5_C_A02_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C4_C5_0_50))
                 (at start (not_occupied seg_C5_C_A02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_WURST))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_C5_C6_0_50))
                 (over all (not_occupied seg_C5_C_B02_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C4_C5_0_50)))
                 (at end (not_occupied seg_C4_C5_0_50))
                 (at end (not (at-segment ?a seg_C4_C5_0_50)))

                 (at start (occupied seg_C5_C_A02_0_100))
                 (at start (not (not_occupied seg_C5_C_A02_0_100)))
                 (at start (blocked seg_C5_C_A02_0_100 ?a))
                 (at start (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (at-segment ?a seg_C5_C_A02_0_100))

                 (at end (not (blocked seg_C3_C4_0_50 ?a)))
                 (at end (not_blocked seg_C3_C4_0_50 ?a))

                 (at end (blocked seg_C5_C6_0_50 ?a))
                 (at end (not (not_blocked seg_C5_C6_0_50 ?a)))
                 (at end (blocked seg_C5_C_B02_0_100 ?a))
                 (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
                )
)

(:durative-action move_seg_C5_C_A02_0_100_seg_A02_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C5_C_A02_0_100))
                 (at start (not_occupied seg_A02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_A02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_A02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_A02_0_100 airplane_WURST))
                 (at start (not_blocked seg_A02_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C5_C_A02_0_100)))
                 (at end (not_occupied seg_C5_C_A02_0_100))
                 (at end (not (at-segment ?a seg_C5_C_A02_0_100)))

                 (at start (occupied seg_A02_0_100))
                 (at start (not (not_occupied seg_A02_0_100)))
                 (at start (blocked seg_A02_0_100 ?a))
                 (at start (not (not_blocked seg_A02_0_100 ?a)))
                 (at end (at-segment ?a seg_A02_0_100))

                 (at end (not (blocked seg_C4_C5_0_50 ?a)))
                 (at end (not_blocked seg_C4_C5_0_50 ?a))
                 (at end (not (blocked seg_C5_C6_0_50 ?a)))
                 (at end (not_blocked seg_C5_C6_0_50 ?a))
                 (at end (not (blocked seg_C5_C_B02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_B02_0_100 ?a))

                )
)

(:durative-action move_seg_B01_0_100_seg_C3_C_B01_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_B01_0_100))
                 (at start (not_occupied seg_C3_C_B01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_WURST))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_B01_0_100)))
                 (at end (not_occupied seg_B01_0_100))
                 (at end (not (at-segment ?a seg_B01_0_100)))

                 (at start (occupied seg_C3_C_B01_0_100))
                 (at start (not (not_occupied seg_C3_C_B01_0_100)))
                 (at start (blocked seg_C3_C_B01_0_100 ?a))
                 (at start (not (not_blocked seg_C3_C_B01_0_100 ?a)))
                 (at end (at-segment ?a seg_C3_C_B01_0_100))


                )
)

(:durative-action move_seg_C3_C_B01_0_100_seg_C3_C4_0_50_north_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C3_C_B01_0_100))
                 (at start (not_occupied seg_C3_C4_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_WURST))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_HOLGI))

                 (over all (not_occupied seg_C2_C3_0_100))
                 (over all (not_occupied seg_C3_C_A01_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C3_C_B01_0_100)))
                 (at end (not_occupied seg_C3_C_B01_0_100))
                 (at end (not (at-segment ?a seg_C3_C_B01_0_100)))

                 (at start (occupied seg_C3_C4_0_50))
                 (at start (not (not_occupied seg_C3_C4_0_50)))
                 (at start (blocked seg_C3_C4_0_50 ?a))
                 (at start (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (at-segment ?a seg_C3_C4_0_50))
                 (at end (not (facing ?a north)))
                 (at end (facing ?a south))

                 (at end (not (blocked seg_B01_0_100 ?a)))
                 (at end (not_blocked seg_B01_0_100 ?a))

                 (at end (blocked seg_C2_C3_0_100 ?a))
                 (at end (not (not_blocked seg_C2_C3_0_100 ?a)))
                 (at end (blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                )
)

(:durative-action move_seg_C2_C3_0_100_seg_C3_C_B01_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C2_C3_0_100))
                 (at start (not_occupied seg_C3_C_B01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_WURST))
                 (at start (not_blocked seg_C3_C_B01_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_C3_C4_0_50))
                 (over all (not_occupied seg_C3_C_A01_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C2_C3_0_100)))
                 (at end (not_occupied seg_C2_C3_0_100))
                 (at end (not (at-segment ?a seg_C2_C3_0_100)))

                 (at start (occupied seg_C3_C_B01_0_100))
                 (at start (not (not_occupied seg_C3_C_B01_0_100)))
                 (at start (blocked seg_C3_C_B01_0_100 ?a))
                 (at start (not (not_blocked seg_C3_C_B01_0_100 ?a)))
                 (at end (at-segment ?a seg_C3_C_B01_0_100))

                 (at end (not (blocked seg_C_C2_0_100 ?a)))
                 (at end (not_blocked seg_C_C2_0_100 ?a))

                 (at end (blocked seg_C3_C4_0_50 ?a))
                 (at end (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                )
)

(:durative-action move_seg_C3_C_B01_0_100_seg_B01_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C3_C_B01_0_100))
                 (at start (not_occupied seg_B01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_B01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_B01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_B01_0_100 airplane_WURST))
                 (at start (not_blocked seg_B01_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C3_C_B01_0_100)))
                 (at end (not_occupied seg_C3_C_B01_0_100))
                 (at end (not (at-segment ?a seg_C3_C_B01_0_100)))

                 (at start (occupied seg_B01_0_100))
                 (at start (not (not_occupied seg_B01_0_100)))
                 (at start (blocked seg_B01_0_100 ?a))
                 (at start (not (not_blocked seg_B01_0_100 ?a)))
                 (at end (at-segment ?a seg_B01_0_100))

                 (at end (not (blocked seg_C2_C3_0_100 ?a)))
                 (at end (not_blocked seg_C2_C3_0_100 ?a))
                 (at end (not (blocked seg_C3_C4_0_50 ?a)))
                 (at end (not_blocked seg_C3_C4_0_50 ?a))
                 (at end (not (blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_A01_0_100 ?a))

                )
)

(:durative-action move_seg_B02_0_100_seg_C5_C_B02_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_B02_0_100))
                 (at start (not_occupied seg_C5_C_B02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_WURST))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_B02_0_100)))
                 (at end (not_occupied seg_B02_0_100))
                 (at end (not (at-segment ?a seg_B02_0_100)))

                 (at start (occupied seg_C5_C_B02_0_100))
                 (at start (not (not_occupied seg_C5_C_B02_0_100)))
                 (at start (blocked seg_C5_C_B02_0_100 ?a))
                 (at start (not (not_blocked seg_C5_C_B02_0_100 ?a)))
                 (at end (at-segment ?a seg_C5_C_B02_0_100))


                )
)

(:durative-action move_seg_C5_C_B02_0_100_seg_C5_C6_0_50_north_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C5_C_B02_0_100))
                 (at start (not_occupied seg_C5_C6_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_WURST))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_HOLGI))

                 (over all (not_occupied seg_C4_C5_0_50))
                 (over all (not_occupied seg_C5_C_A02_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C5_C_B02_0_100)))
                 (at end (not_occupied seg_C5_C_B02_0_100))
                 (at end (not (at-segment ?a seg_C5_C_B02_0_100)))

                 (at start (occupied seg_C5_C6_0_50))
                 (at start (not (not_occupied seg_C5_C6_0_50)))
                 (at start (blocked seg_C5_C6_0_50 ?a))
                 (at start (not (not_blocked seg_C5_C6_0_50 ?a)))
                 (at end (at-segment ?a seg_C5_C6_0_50))
                 (at end (not (facing ?a north)))
                 (at end (facing ?a south))

                 (at end (not (blocked seg_B02_0_100 ?a)))
                 (at end (not_blocked seg_B02_0_100 ?a))

                 (at end (blocked seg_C4_C5_0_50 ?a))
                 (at end (not (not_blocked seg_C4_C5_0_50 ?a)))
                 (at end (blocked seg_C5_C_A02_0_100 ?a))
                 (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                )
)

(:durative-action move_seg_C4_C5_0_50_seg_C5_C_B02_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 1)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C4_C5_0_50))
                 (at start (not_occupied seg_C5_C_B02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_WURST))
                 (at start (not_blocked seg_C5_C_B02_0_100 airplane_HOLGI))

                 (over all (not_occupied seg_C5_C6_0_50))
                 (over all (not_occupied seg_C5_C_A02_0_100))
              )

 :effect        (and
                 (at end (not (occupied seg_C4_C5_0_50)))
                 (at end (not_occupied seg_C4_C5_0_50))
                 (at end (not (at-segment ?a seg_C4_C5_0_50)))

                 (at start (occupied seg_C5_C_B02_0_100))
                 (at start (not (not_occupied seg_C5_C_B02_0_100)))
                 (at start (blocked seg_C5_C_B02_0_100 ?a))
                 (at start (not (not_blocked seg_C5_C_B02_0_100 ?a)))
                 (at end (at-segment ?a seg_C5_C_B02_0_100))

                 (at end (not (blocked seg_C3_C4_0_50 ?a)))
                 (at end (not_blocked seg_C3_C4_0_50 ?a))

                 (at end (blocked seg_C5_C6_0_50 ?a))
                 (at end (not (not_blocked seg_C5_C6_0_50 ?a)))
                 (at end (blocked seg_C5_C_A02_0_100 ?a))
                 (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                )
)

(:durative-action move_seg_C5_C_B02_0_100_seg_B02_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the speed of an airplane (fixed 30 m/s)
             (= ?duration 3)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-moving ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C5_C_B02_0_100))
                 (at start (not_occupied seg_B02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_B02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_B02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_B02_0_100 airplane_WURST))
                 (at start (not_blocked seg_B02_0_100 airplane_HOLGI))

              )

 :effect        (and
                 (at end (not (occupied seg_C5_C_B02_0_100)))
                 (at end (not_occupied seg_C5_C_B02_0_100))
                 (at end (not (at-segment ?a seg_C5_C_B02_0_100)))

                 (at start (occupied seg_B02_0_100))
                 (at start (not (not_occupied seg_B02_0_100)))
                 (at start (blocked seg_B02_0_100 ?a))
                 (at start (not (not_blocked seg_B02_0_100 ?a)))
                 (at end (at-segment ?a seg_B02_0_100))

                 (at end (not (blocked seg_C4_C5_0_50 ?a)))
                 (at end (not_blocked seg_C4_C5_0_50 ?a))
                 (at end (not (blocked seg_C5_C6_0_50 ?a)))
                 (at end (not_blocked seg_C5_C6_0_50 ?a))
                 (at end (not (blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_A02_0_100 ?a))

                )
)

(:durative-action pushback_seg_A01_0_100_seg_C3_C_A01_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the pushbackspeed of an airplane (fixed 5 m/s)
             (= ?duration 20)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-pushing ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_A01_0_100))
                 (at start (not_occupied seg_C3_C_A01_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_WURST))
                 (at start (not_blocked seg_C3_C_A01_0_100 airplane_HOLGI))
                )

 :effect        (and
                 (at end (not (occupied seg_A01_0_100)))
                 (at end (not_occupied seg_A01_0_100))
                 (at end (not (blocked seg_A01_0_100 ?a)))
                 (at end (not_blocked seg_A01_0_100 ?a))
                 (at end (not (at-segment ?a seg_A01_0_100)))

                 (at start (occupied seg_C3_C_A01_0_100))
                 (at start (not (not_occupied seg_C3_C_A01_0_100)))
                 (at start (blocked seg_C3_C_A01_0_100 ?a))
                 (at start (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (at-segment ?a seg_C3_C_A01_0_100))

                )
)

(:durative-action pushback_seg_C3_C_A01_0_100_seg_C3_C4_0_50_south_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the pushbackspeed of an airplane (fixed 5 m/s)
             (= ?duration 20)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-pushing ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C3_C_A01_0_100))
                 (at start (not_occupied seg_C3_C4_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_WURST))
                 (at start (not_blocked seg_C3_C4_0_50 airplane_HOLGI))
                )

 :effect        (and
                 (at end (not (occupied seg_C3_C_A01_0_100)))
                 (at end (not_occupied seg_C3_C_A01_0_100))
                 (at end (not (blocked seg_C3_C_A01_0_100 ?a)))
                 (at end (not_blocked seg_C3_C_A01_0_100 ?a))
                 (at end (not (at-segment ?a seg_C3_C_A01_0_100)))

                 (at start (occupied seg_C3_C4_0_50))
                 (at start (not (not_occupied seg_C3_C4_0_50)))
                 (at start (blocked seg_C3_C4_0_50 ?a))
                 (at start (not (not_blocked seg_C3_C4_0_50 ?a)))
                 (at end (at-segment ?a seg_C3_C4_0_50))
                 (at end (not (facing ?a south)))
                 (at end (facing ?a north))

                )
)

(:durative-action pushback_seg_C3_C4_0_50_seg_C4_C5_0_50_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the pushbackspeed of an airplane (fixed 5 m/s)
             (= ?duration 10)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-pushing ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C3_C4_0_50))
                 (at start (not_occupied seg_C4_C5_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_WURST))
                 (at start (not_blocked seg_C4_C5_0_50 airplane_HOLGI))
                )

 :effect        (and
                 (at end (not (occupied seg_C3_C4_0_50)))
                 (at end (not_occupied seg_C3_C4_0_50))
                 (at end (not (blocked seg_C3_C4_0_50 ?a)))
                 (at end (not_blocked seg_C3_C4_0_50 ?a))
                 (at end (not (at-segment ?a seg_C3_C4_0_50)))

                 (at start (occupied seg_C4_C5_0_50))
                 (at start (not (not_occupied seg_C4_C5_0_50)))
                 (at start (blocked seg_C4_C5_0_50 ?a))
                 (at start (not (not_blocked seg_C4_C5_0_50 ?a)))
                 (at end (at-segment ?a seg_C4_C5_0_50))

                )
)

(:durative-action pushback_seg_A02_0_100_seg_C5_C_A02_0_100_south_south_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the pushbackspeed of an airplane (fixed 5 m/s)
             (= ?duration 20)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-pushing ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_A02_0_100))
                 (at start (not_occupied seg_C5_C_A02_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_WURST))
                 (at start (not_blocked seg_C5_C_A02_0_100 airplane_HOLGI))
                )

 :effect        (and
                 (at end (not (occupied seg_A02_0_100)))
                 (at end (not_occupied seg_A02_0_100))
                 (at end (not (blocked seg_A02_0_100 ?a)))
                 (at end (not_blocked seg_A02_0_100 ?a))
                 (at end (not (at-segment ?a seg_A02_0_100)))

                 (at start (occupied seg_C5_C_A02_0_100))
                 (at start (not (not_occupied seg_C5_C_A02_0_100)))
                 (at start (blocked seg_C5_C_A02_0_100 ?a))
                 (at start (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (at-segment ?a seg_C5_C_A02_0_100))

                )
)

(:durative-action pushback_seg_C5_C_A02_0_100_seg_C5_C6_0_50_south_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the pushbackspeed of an airplane (fixed 5 m/s)
             (= ?duration 20)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-pushing ?a))
                 (at start (facing ?a south))
                 (at start (at-segment ?a seg_C5_C_A02_0_100))
                 (at start (not_occupied seg_C5_C6_0_50))
                 (at start (landing_started))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_CFBEG))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_DAEWH))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_WURST))
                 (at start (not_blocked seg_C5_C6_0_50 airplane_HOLGI))
                )

 :effect        (and
                 (at end (not (occupied seg_C5_C_A02_0_100)))
                 (at end (not_occupied seg_C5_C_A02_0_100))
                 (at end (not (blocked seg_C5_C_A02_0_100 ?a)))
                 (at end (not_blocked seg_C5_C_A02_0_100 ?a))
                 (at end (not (at-segment ?a seg_C5_C_A02_0_100)))

                 (at start (occupied seg_C5_C6_0_50))
                 (at start (not (not_occupied seg_C5_C6_0_50)))
                 (at start (blocked seg_C5_C6_0_50 ?a))
                 (at start (not (not_blocked seg_C5_C6_0_50 ?a)))
                 (at end (at-segment ?a seg_C5_C6_0_50))
                 (at end (not (facing ?a south)))
                 (at end (facing ?a north))

                )
)

(:durative-action pushback_seg_C5_C6_0_50_seg_C6_C7_0_100_north_north_medium

 :parameters    (?a - airplane)

 :duration
             ;; length of the segment divided through the pushbackspeed of an airplane (fixed 5 m/s)
             (= ?duration 10)

 :condition  (and
                 (over all (has-type ?a medium))
                 (over all (is-pushing ?a))
                 (at start (facing ?a north))
                 (at start (at-segment ?a seg_C5_C6_0_50))
                 (at start (not_occupied seg_C6_C7_0_100))
                 (at start (landing_started))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_CFBEG))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_DAEWH))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_WURST))
                 (at start (not_blocked seg_C6_C7_0_100 airplane_HOLGI))
                )

 :effect        (and
                 (at end (not (occupied seg_C5_C6_0_50)))
                 (at end (not_occupied seg_C5_C6_0_50))
                 (at end (not (blocked seg_C5_C6_0_50 ?a)))
                 (at end (not_blocked seg_C5_C6_0_50 ?a))
                 (at end (not (at-segment ?a seg_C5_C6_0_50)))

                 (at start (occupied seg_C6_C7_0_100))
                 (at start (not (not_occupied seg_C6_C7_0_100)))
                 (at start (blocked seg_C6_C7_0_100 ?a))
                 (at start (not (not_blocked seg_C6_C7_0_100 ?a)))
                 (at end (at-segment ?a seg_C6_C7_0_100))

                )
)


(:durative-action takeoff_seg_27_0_150_north

 :parameters (?a - airplane)

 :duration  (= ?duration 30 )

 :condition    (and (at start (at-segment ?a seg_27_0_150))
                    (at start (facing ?a north))
                    (at start (is-moving ?a))
                    (at start (landing_started))
               )

 :effect (and (at end (not (occupied seg_27_0_150)))
              (at end (not_occupied seg_27_0_150))
              (at end (not (blocked seg_27_0_150 ?a)))
              (at end (not_blocked seg_27_0_150 ?a))
              (at end (not (at-segment ?a seg_27_0_150)))
              (at end (airborne ?a seg_27_0_150))
              (at end (not (is-moving ?a )))
              (at end (not (blocked seg_B_27_0_100 ?a)))
              (at end (not_blocked seg_B_27_0_100 ?a))
         )
)

(:durative-action takeoff_seg_09_0_150_south

 :parameters (?a - airplane)

 :duration  (= ?duration 30 )

 :condition    (and (at start (at-segment ?a seg_09_0_150))
                    (at start (facing ?a south))
                    (at start (is-moving ?a))
                    (at start (landing_started))
               )

 :effect (and (at end (not (occupied seg_09_0_150)))
              (at end (not_occupied seg_09_0_150))
              (at end (not (blocked seg_09_0_150 ?a)))
              (at end (not_blocked seg_09_0_150 ?a))
              (at end (not (at-segment ?a seg_09_0_150)))
              (at end (airborne ?a seg_09_0_150))
              (at end (not (is-moving ?a )))
              (at end (not (blocked seg_A_09_0_100 ?a)))
              (at end (not_blocked seg_A_09_0_100 ?a))
         )
)


(:durative-action startup_seg_A_09_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_A_09_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_09Help_0_100))
                    (over all (not_occupied seg_09_0_150))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_09Help_0_100 ?a))
                    (at end (not (not_blocked seg_09Help_0_100 ?a)))
                    (at end (blocked seg_09_0_150 ?a))
                    (at end (not (not_blocked seg_09_0_150 ?a)))
         )
)
(:durative-action startup_seg_A_09_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_A_09_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N1_A_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N1_A_0_100 ?a))
                    (at end (not (not_blocked seg_N1_A_0_100 ?a)))
         )
)
(:durative-action startup_seg_B_27_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_B_27_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_27_0_150))
                    (over all (not_occupied seg_27Help_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_27_0_150 ?a))
                    (at end (not (not_blocked seg_27_0_150 ?a)))
                    (at end (blocked seg_27Help_0_100 ?a))
                    (at end (not (not_blocked seg_27Help_0_100 ?a)))
         )
)
(:durative-action startup_seg_B_27_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_B_27_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N6_B_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N6_B_0_100 ?a))
                    (at end (not (not_blocked seg_N6_B_0_100 ?a)))
         )
)
(:durative-action startup_seg_N1_N2_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N1_N2_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_1_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_1_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_1_0_86 ?a)))
         )
)
(:durative-action startup_seg_N1_N2_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N1_N2_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N1_A_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N1_A_0_100 ?a))
                    (at end (not (not_blocked seg_N1_A_0_100 ?a)))
         )
)
(:durative-action startup_seg_N1_A_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N1_A_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_A_09_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_A_09_0_100 ?a))
                    (at end (not (not_blocked seg_A_09_0_100 ?a)))
         )
)
(:durative-action startup_seg_N1_A_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N1_A_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N1_N2_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N1_N2_0_100 ?a))
                    (at end (not (not_blocked seg_N1_N2_0_100 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_1_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_1_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_2_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_2_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_2_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_1_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_1_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N1_N2_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N1_N2_0_100 ?a))
                    (at end (not (not_blocked seg_N1_N2_0_100 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_0_85_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N3_N_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N3_N_0_100 ?a))
                    (at end (not (not_blocked seg_N3_N_0_100 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_0_85_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_6_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_6_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_6_0_86 ?a)))
         )
)
(:durative-action startup_seg_N3_N_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N3_N_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N_N4_0_100))
                    (over all (not_occupied seg_N_C_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N_N4_0_100 ?a))
                    (at end (not (not_blocked seg_N_N4_0_100 ?a)))
                    (at end (blocked seg_N_C_0_100 ?a))
                    (at end (not (not_blocked seg_N_C_0_100 ?a)))
         )
)
(:durative-action startup_seg_N3_N_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N3_N_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_0_85 ?a))
                    (at end (not (not_blocked seg_N2_N3_0_85 ?a)))
         )
)
(:durative-action startup_seg_N_N4_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N_N4_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_1_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_1_0_85 ?a))
                    (at end (not (not_blocked seg_N4_N5_1_0_85 ?a)))
         )
)
(:durative-action startup_seg_N_N4_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N_N4_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N3_N_0_100))
                    (over all (not_occupied seg_N_C_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N3_N_0_100 ?a))
                    (at end (not (not_blocked seg_N3_N_0_100 ?a)))
                    (at end (blocked seg_N_C_0_100 ?a))
                    (at end (not (not_blocked seg_N_C_0_100 ?a)))
         )
)
(:durative-action startup_seg_N_C_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N_C_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C_C2_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C_C2_0_100 ?a))
                    (at end (not (not_blocked seg_C_C2_0_100 ?a)))
         )
)
(:durative-action startup_seg_N_C_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N_C_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N3_N_0_100))
                    (over all (not_occupied seg_N_N4_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N3_N_0_100 ?a))
                    (at end (not (not_blocked seg_N3_N_0_100 ?a)))
                    (at end (blocked seg_N_N4_0_100 ?a))
                    (at end (not (not_blocked seg_N_N4_0_100 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_1_0_85_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_1_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_2_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_2_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_2_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_1_0_85_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_1_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N_N4_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N_N4_0_100 ?a))
                    (at end (not (not_blocked seg_N_N4_0_100 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N5_N6_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N5_N6_0_100 ?a))
                    (at end (not (not_blocked seg_N5_N6_0_100 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_6_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_6_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_6_0_86 ?a)))
         )
)
(:durative-action startup_seg_N5_N6_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N5_N6_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N6_B_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N6_B_0_100 ?a))
                    (at end (not (not_blocked seg_N6_B_0_100 ?a)))
         )
)
(:durative-action startup_seg_N5_N6_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N5_N6_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_0_86 ?a)))
         )
)
(:durative-action startup_seg_N6_B_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N6_B_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_B_27_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_B_27_0_100 ?a))
                    (at end (not (not_blocked seg_B_27_0_100 ?a)))
         )
)
(:durative-action startup_seg_N6_B_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N6_B_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N5_N6_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N5_N6_0_100 ?a))
                    (at end (not (not_blocked seg_N5_N6_0_100 ?a)))
         )
)
(:durative-action startup_seg_C_C2_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C_C2_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C2_C3_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C2_C3_0_100 ?a))
                    (at end (not (not_blocked seg_C2_C3_0_100 ?a)))
         )
)
(:durative-action startup_seg_C_C2_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C_C2_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_N_C_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N_C_0_100 ?a))
                    (at end (not (not_blocked seg_N_C_0_100 ?a)))
         )
)
(:durative-action startup_seg_C2_C3_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C2_C3_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C3_C4_0_50))
                    (over all (not_occupied seg_C3_C_A01_0_100))
                    (over all (not_occupied seg_C3_C_B01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C3_C4_0_50 ?a))
                    (at end (not (not_blocked seg_C3_C4_0_50 ?a)))
                    (at end (blocked seg_C3_C_A01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                    (at end (blocked seg_C3_C_B01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
         )
)
(:durative-action startup_seg_C2_C3_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C2_C3_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C_C2_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C_C2_0_100 ?a))
                    (at end (not (not_blocked seg_C_C2_0_100 ?a)))
         )
)
(:durative-action startup_seg_C3_C4_0_50_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C3_C4_0_50))
                    (at start (landing_started))
                    (over all (not_occupied seg_C4_C5_0_50))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C4_C5_0_50 ?a))
                    (at end (not (not_blocked seg_C4_C5_0_50 ?a)))
         )
)
(:durative-action startup_seg_C3_C4_0_50_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C3_C4_0_50))
                    (at start (landing_started))
                    (over all (not_occupied seg_C2_C3_0_100))
                    (over all (not_occupied seg_C3_C_A01_0_100))
                    (over all (not_occupied seg_C3_C_B01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C2_C3_0_100 ?a))
                    (at end (not (not_blocked seg_C2_C3_0_100 ?a)))
                    (at end (blocked seg_C3_C_A01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
                    (at end (blocked seg_C3_C_B01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
         )
)
(:durative-action startup_seg_C3_C_A01_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C3_C_A01_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_A01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_A01_0_100 ?a))
                    (at end (not (not_blocked seg_A01_0_100 ?a)))
         )
)
(:durative-action startup_seg_C3_C_A01_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C3_C_A01_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C2_C3_0_100))
                    (over all (not_occupied seg_C3_C4_0_50))
                    (over all (not_occupied seg_C3_C_B01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C2_C3_0_100 ?a))
                    (at end (not (not_blocked seg_C2_C3_0_100 ?a)))
                    (at end (blocked seg_C3_C4_0_50 ?a))
                    (at end (not (not_blocked seg_C3_C4_0_50 ?a)))
                    (at end (blocked seg_C3_C_B01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
         )
)
(:durative-action startup_seg_C3_C_B01_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C3_C_B01_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_B01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_B01_0_100 ?a))
                    (at end (not (not_blocked seg_B01_0_100 ?a)))
         )
)
(:durative-action startup_seg_C3_C_B01_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C3_C_B01_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C2_C3_0_100))
                    (over all (not_occupied seg_C3_C4_0_50))
                    (over all (not_occupied seg_C3_C_A01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C2_C3_0_100 ?a))
                    (at end (not (not_blocked seg_C2_C3_0_100 ?a)))
                    (at end (blocked seg_C3_C4_0_50 ?a))
                    (at end (not (not_blocked seg_C3_C4_0_50 ?a)))
                    (at end (blocked seg_C3_C_A01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
         )
)
(:durative-action startup_seg_C4_C5_0_50_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C4_C5_0_50))
                    (at start (landing_started))
                    (over all (not_occupied seg_C5_C6_0_50))
                    (over all (not_occupied seg_C5_C_A02_0_100))
                    (over all (not_occupied seg_C5_C_B02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C5_C6_0_50 ?a))
                    (at end (not (not_blocked seg_C5_C6_0_50 ?a)))
                    (at end (blocked seg_C5_C_A02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                    (at end (blocked seg_C5_C_B02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
         )
)
(:durative-action startup_seg_C4_C5_0_50_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C4_C5_0_50))
                    (at start (landing_started))
                    (over all (not_occupied seg_C3_C4_0_50))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C3_C4_0_50 ?a))
                    (at end (not (not_blocked seg_C3_C4_0_50 ?a)))
         )
)
(:durative-action startup_seg_C5_C6_0_50_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C5_C6_0_50))
                    (at start (landing_started))
                    (over all (not_occupied seg_C6_C7_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C6_C7_0_100 ?a))
                    (at end (not (not_blocked seg_C6_C7_0_100 ?a)))
         )
)
(:durative-action startup_seg_C5_C6_0_50_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C5_C6_0_50))
                    (at start (landing_started))
                    (over all (not_occupied seg_C4_C5_0_50))
                    (over all (not_occupied seg_C5_C_A02_0_100))
                    (over all (not_occupied seg_C5_C_B02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C4_C5_0_50 ?a))
                    (at end (not (not_blocked seg_C4_C5_0_50 ?a)))
                    (at end (blocked seg_C5_C_A02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
                    (at end (blocked seg_C5_C_B02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
         )
)
(:durative-action startup_seg_C5_C_A02_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C5_C_A02_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_A02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_A02_0_100 ?a))
                    (at end (not (not_blocked seg_A02_0_100 ?a)))
         )
)
(:durative-action startup_seg_C5_C_A02_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C5_C_A02_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C4_C5_0_50))
                    (over all (not_occupied seg_C5_C6_0_50))
                    (over all (not_occupied seg_C5_C_B02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C4_C5_0_50 ?a))
                    (at end (not (not_blocked seg_C4_C5_0_50 ?a)))
                    (at end (blocked seg_C5_C6_0_50 ?a))
                    (at end (not (not_blocked seg_C5_C6_0_50 ?a)))
                    (at end (blocked seg_C5_C_B02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
         )
)
(:durative-action startup_seg_C5_C_B02_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C5_C_B02_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_B02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_B02_0_100 ?a))
                    (at end (not (not_blocked seg_B02_0_100 ?a)))
         )
)
(:durative-action startup_seg_C5_C_B02_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C5_C_B02_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C4_C5_0_50))
                    (over all (not_occupied seg_C5_C6_0_50))
                    (over all (not_occupied seg_C5_C_A02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C4_C5_0_50 ?a))
                    (at end (not (not_blocked seg_C4_C5_0_50 ?a)))
                    (at end (blocked seg_C5_C6_0_50 ?a))
                    (at end (not (not_blocked seg_C5_C6_0_50 ?a)))
                    (at end (blocked seg_C5_C_A02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
         )
)
(:durative-action startup_seg_C6_C7_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C6_C7_0_100))
                    (at start (landing_started))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
         )
)
(:durative-action startup_seg_C6_C7_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_C6_C7_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C5_C6_0_50))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C5_C6_0_50 ?a))
                    (at end (not (not_blocked seg_C5_C6_0_50 ?a)))
         )
)
(:durative-action park_seg_A01_0_100_north
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_A01_0_100))
                    (over all (facing ?a north))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_A01_0_100))
              (at end (not (is-moving ?a)))
         )
)
(:durative-action park_seg_A01_0_100_south
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_A01_0_100))
                    (over all (facing ?a south))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_A01_0_100))
              (at end (not (is-moving ?a)))
              (at end (not (blocked seg_C3_C_A01_0_100 ?a)))
              (at end (not_blocked seg_C3_C_A01_0_100 ?a))
         )
)
(:durative-action startup_seg_A01_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_A01_0_100))
                    (at start (landing_started))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
         )
)
(:durative-action startup_seg_A01_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_A01_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C3_C_A01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C3_C_A01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_A01_0_100 ?a)))
         )
)
(:durative-action park_seg_A02_0_100_north
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_A02_0_100))
                    (over all (facing ?a north))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_A02_0_100))
              (at end (not (is-moving ?a)))
         )
)
(:durative-action park_seg_A02_0_100_south
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_A02_0_100))
                    (over all (facing ?a south))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_A02_0_100))
              (at end (not (is-moving ?a)))
              (at end (not (blocked seg_C5_C_A02_0_100 ?a)))
              (at end (not_blocked seg_C5_C_A02_0_100 ?a))
         )
)
(:durative-action startup_seg_A02_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_A02_0_100))
                    (at start (landing_started))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
         )
)
(:durative-action startup_seg_A02_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_A02_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C5_C_A02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C5_C_A02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_A02_0_100 ?a)))
         )
)
(:durative-action park_seg_B01_0_100_north
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_B01_0_100))
                    (over all (facing ?a north))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_B01_0_100))
              (at end (not (is-moving ?a)))
         )
)
(:durative-action park_seg_B01_0_100_south
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_B01_0_100))
                    (over all (facing ?a south))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_B01_0_100))
              (at end (not (is-moving ?a)))
              (at end (not (blocked seg_C3_C_B01_0_100 ?a)))
              (at end (not_blocked seg_C3_C_B01_0_100 ?a))
         )
)
(:durative-action startup_seg_B01_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_B01_0_100))
                    (at start (landing_started))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
         )
)
(:durative-action startup_seg_B01_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_B01_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C3_C_B01_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C3_C_B01_0_100 ?a))
                    (at end (not (not_blocked seg_C3_C_B01_0_100 ?a)))
         )
)
(:durative-action park_seg_B02_0_100_north
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_B02_0_100))
                    (over all (facing ?a north))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_B02_0_100))
              (at end (not (is-moving ?a)))
         )
)
(:durative-action park_seg_B02_0_100_south
 :parameters (?a - airplane)
 :duration (= ?duration 40)
 :condition (and    (over all (at-segment ?a seg_B02_0_100))
                    (over all (facing ?a south))
                    (at start (is-moving ?a))
            )
 :effect (and (at end (is-parked ?a seg_B02_0_100))
              (at end (not (is-moving ?a)))
              (at end (not (blocked seg_C5_C_B02_0_100 ?a)))
              (at end (not_blocked seg_C5_C_B02_0_100 ?a))
         )
)
(:durative-action startup_seg_B02_0_100_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_B02_0_100))
                    (at start (landing_started))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
         )
)
(:durative-action startup_seg_B02_0_100_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_B02_0_100))
                    (at start (landing_started))
                    (over all (not_occupied seg_C5_C_B02_0_100))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_C5_C_B02_0_100 ?a))
                    (at end (not (not_blocked seg_C5_C_B02_0_100 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_2_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_2_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_3_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_3_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_3_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_2_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_2_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_1_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_1_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_1_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_3_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_3_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_4_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_4_0_85 ?a))
                    (at end (not (not_blocked seg_N2_N3_4_0_85 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_3_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_3_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_2_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_2_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_2_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_4_0_85_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_4_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_5_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_5_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_5_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_4_0_85_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_4_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_3_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_3_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_3_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_5_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_5_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_6_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_6_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_6_0_86 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_5_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_5_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_4_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_4_0_85 ?a))
                    (at end (not (not_blocked seg_N2_N3_4_0_85 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_6_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_6_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_0_85 ?a))
                    (at end (not (not_blocked seg_N2_N3_0_85 ?a)))
         )
)
(:durative-action startup_seg_N2_N3_6_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N2_N3_6_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N2_N3_5_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N2_N3_5_0_86 ?a))
                    (at end (not (not_blocked seg_N2_N3_5_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_2_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_2_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_3_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_3_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_3_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_2_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_2_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_1_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_1_0_85 ?a))
                    (at end (not (not_blocked seg_N4_N5_1_0_85 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_3_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_3_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_4_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_4_0_85 ?a))
                    (at end (not (not_blocked seg_N4_N5_4_0_85 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_3_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_3_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_2_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_2_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_2_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_4_0_85_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_4_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_5_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_5_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_5_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_4_0_85_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_4_0_85))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_3_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_3_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_3_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_5_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_5_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_6_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_6_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_6_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_5_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_5_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_4_0_85))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_4_0_85 ?a))
                    (at end (not (not_blocked seg_N4_N5_4_0_85 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_6_0_86_north_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_6_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_0_86 ?a)))
         )
)
(:durative-action startup_seg_N4_N5_6_0_86_south_medium

 :parameters (?a - airplane)

 :duration  (= ?duration (* 60 (engines ?a) ) )

 :condition    (and (at start (is-pushing ?a))
                    (over all (at-segment ?a seg_N4_N5_6_0_86))
                    (at start (landing_started))
                    (over all (not_occupied seg_N4_N5_5_0_86))
               )

 :effect       (and (at end (not (is-pushing ?a)))
                    (at end (is-moving ?a))
                    (at end (blocked seg_N4_N5_5_0_86 ?a))
                    (at end (not (not_blocked seg_N4_N5_5_0_86 ?a)))
         )
)

(:durative-action idle_1
 :parameters ()
 :duration (= ?duration 248)
 :condition (and
                 (over all (idled_0))
                 (over all (landing_global))
            )
 :effect    (and
                 (at end (idled_1))
                 (at end (not (idled_0)))
            )
)
(:durative-action land_1
 :parameters ()
 :duration (= ?duration 30)
 :condition (and
                 (over all (idled_1))
                 (over all (landing_global))
            )
 :effect    (and
                (at end (landed_1))
                (at end (not (idled_1)))
                (at start (occupied seg_27Thresh_0_100))
                (at start (not (not_occupied seg_27Thresh_0_100)))
                (at end (not (occupied seg_27Thresh_0_100)))
                (at end (not_occupied seg_27Thresh_0_100))
                (at start (occupied seg_27Help_0_100))
                (at start (not (not_occupied seg_27Help_0_100)))
                (at end (not (occupied seg_27Help_0_100)))
                (at end (not_occupied seg_27Help_0_100))
                (at start (occupied seg_27_0_150))
                (at start (not (not_occupied seg_27_0_150)))
                (at end (not (occupied seg_27_0_150)))
                (at end (not_occupied seg_27_0_150))
                (at start (occupied seg_Rwy_0_1300))
                (at start (not (not_occupied seg_Rwy_0_1300)))
                (at end (not (occupied seg_Rwy_0_1300)))
                (at end (not_occupied seg_Rwy_0_1300))
                (at start (occupied seg_09_0_150))
                (at start (not (not_occupied seg_09_0_150)))
                (at end (not (occupied seg_09_0_150)))
                (at end (not_occupied seg_09_0_150))
                (at start (occupied seg_09Help_0_100))
                (at start (not (not_occupied seg_09Help_0_100)))
                (at end (not (occupied seg_09Help_0_100)))
                (at end (not_occupied seg_09Help_0_100))
                (at start (occupied seg_09Thresh_0_100))
                (at start (not (not_occupied seg_09Thresh_0_100)))
                (at end (not (occupied seg_09Thresh_0_100)))
                (at end (not_occupied seg_09Thresh_0_100))
            )
)
(:durative-action idle_2
 :parameters ()
 :duration (= ?duration 152)
 :condition (and
                 (over all (landed_1))
                 (over all (landing_global))
            )
 :effect    (and
                 (at end (idled_2))
                 (at end (not (landed_1)))
            )
)
(:durative-action land_2
 :parameters ()
 :duration (= ?duration 30)
 :condition (and
                 (over all (idled_2))
                 (over all (landing_global))
            )
 :effect    (and
                (at end (landed_2))
                (at end (not (idled_2)))
                (at start (occupied seg_27Thresh_0_100))
                (at start (not (not_occupied seg_27Thresh_0_100)))
                (at end (not (occupied seg_27Thresh_0_100)))
                (at end (not_occupied seg_27Thresh_0_100))
                (at start (occupied seg_27Help_0_100))
                (at start (not (not_occupied seg_27Help_0_100)))
                (at end (not (occupied seg_27Help_0_100)))
                (at end (not_occupied seg_27Help_0_100))
                (at start (occupied seg_27_0_150))
                (at start (not (not_occupied seg_27_0_150)))
                (at end (not (occupied seg_27_0_150)))
                (at end (not_occupied seg_27_0_150))
                (at start (occupied seg_Rwy_0_1300))
                (at start (not (not_occupied seg_Rwy_0_1300)))
                (at end (not (occupied seg_Rwy_0_1300)))
                (at end (not_occupied seg_Rwy_0_1300))
                (at start (occupied seg_09_0_150))
                (at start (not (not_occupied seg_09_0_150)))
                (at end (not (occupied seg_09_0_150)))
                (at end (not_occupied seg_09_0_150))
                (at start (occupied seg_09Help_0_100))
                (at start (not (not_occupied seg_09Help_0_100)))
                (at end (not (occupied seg_09Help_0_100)))
                (at end (not_occupied seg_09Help_0_100))
                (at start (occupied seg_09Thresh_0_100))
                (at start (not (not_occupied seg_09Thresh_0_100)))
                (at end (not (occupied seg_09Thresh_0_100)))
                (at end (not_occupied seg_09Thresh_0_100))
            )
)
(:durative-action idle_3
 :parameters ()
 :duration (= ?duration 298)
 :condition (and
                 (over all (landed_2))
                 (over all (landing_global))
            )
 :effect    (and
                 (at end (idled_3))
                 (at end (not (landed_2)))
            )
)
(:durative-action land_3
 :parameters ()
 :duration (= ?duration 30)
 :condition (and
                 (over all (idled_3))
                 (over all (landing_global))
            )
 :effect    (and
                (at end (landed_last))
                (at end (not (idled_3)))
                (at start (occupied seg_27Thresh_0_100))
                (at start (not (not_occupied seg_27Thresh_0_100)))
                (at end (not (occupied seg_27Thresh_0_100)))
                (at end (not_occupied seg_27Thresh_0_100))
                (at start (occupied seg_27Help_0_100))
                (at start (not (not_occupied seg_27Help_0_100)))
                (at end (not (occupied seg_27Help_0_100)))
                (at end (not_occupied seg_27Help_0_100))
                (at start (occupied seg_27_0_150))
                (at start (not (not_occupied seg_27_0_150)))
                (at end (not (occupied seg_27_0_150)))
                (at end (not_occupied seg_27_0_150))
                (at start (occupied seg_Rwy_0_1300))
                (at start (not (not_occupied seg_Rwy_0_1300)))
                (at end (not (occupied seg_Rwy_0_1300)))
                (at end (not_occupied seg_Rwy_0_1300))
                (at start (occupied seg_09_0_150))
                (at start (not (not_occupied seg_09_0_150)))
                (at end (not (occupied seg_09_0_150)))
                (at end (not_occupied seg_09_0_150))
                (at start (occupied seg_09Help_0_100))
                (at start (not (not_occupied seg_09Help_0_100)))
                (at end (not (occupied seg_09Help_0_100)))
                (at end (not_occupied seg_09Help_0_100))
                (at start (occupied seg_09Thresh_0_100))
                (at start (not (not_occupied seg_09Thresh_0_100)))
                (at end (not (occupied seg_09Thresh_0_100)))
                (at end (not_occupied seg_09Thresh_0_100))
            )
)
(:durative-action landing_wrapper
 :parameters ()
 :duration (= ?duration 788)
 :condition (and
               (at start (start_landing))
            )
 :effect    (and
                 (at start (not (start_landing)))
                 (at start (landing_started))
                 (at start (idled_0))
                 (at start (landing_global))
                 (at end (not (landing_global)))
            )
)

)
